@@ -46,6 +46,7 @@ FILE_FORMATS = {'wav': 0, 'wave': 0, 'aif': 1, 'aiff': 1, 'au': 2, '': 3, 'sd2':
 FUNCTIONS_INIT_LINES = {"pa_count_host_apis": "pa_count_host_apis()", "pa_list_host_apis": "pa_list_host_apis()",
                         "pa_get_default_host_api": "pa_get_default_host_api()", "pa_count_devices": "pa_count_devices()",
                         "pa_list_devices": "pa_list_devices()", "pa_get_devices_infos": "pa_get_devices_infos()",
+                        "pa_get_version": "pa_get_version()", "pa_get_version_text": "pa_get_version_text()",
                         "pa_get_input_devices": "pa_get_input_devices()", "pa_get_output_devices": "pa_get_output_devices()",
                         "pa_get_default_input": "pa_get_default_input()", "pa_get_default_output": "pa_get_default_output()",
                         "pa_get_input_max_channels": "pa_get_input_max_channels(x)", "pa_get_output_max_channels": "pa_get_output_max_channels(x)",
@@ -223,6 +224,9 @@ def getVersion():
     major, minor, rev = PYO_VERSION.split('.')
     return (int(major), int(minor), int(rev))
 
+def dumpref():
+    pass
+
 class PyoError(Exception):
     """Base class for all pyo exceptions."""
 
@@ -286,6 +290,20 @@ class PyoObjectBase(object):
         """
         return self._base_objs
 
+    def cleanFuncRefs(self):
+        """
+        Method used to remove internal references to callback functions.
+        
+        An internal reference to a callback function (ex. the function
+        called by the TrigFunc object) may prevent the object to be
+        properly deleted when its reference count drop to zero. Calling
+        this function just before deleting the last reference will replace
+        the callback reference by a dump ref.
+
+        """
+        if hasattr(self, "_function"):
+            self.setFunction(dumpref)
+
     def __getitem__(self, i):
         if i == 'trig':
             return self._trig_objs
@@ -1123,13 +1141,103 @@ class PyoTableObject(PyoObjectBase):
 
     def reverse(self):
         """
-        Reverse the table's data.
+        Reverse the table's data in time.
 
         """
         [obj.reverse() for obj in self._base_objs]
         self.refreshView()
         return self
 
+    def invert(self):
+        """
+        Reverse the table's data in amplitude.
+
+        """
+        [obj.invert() for obj in self._base_objs]
+        self.refreshView()
+        return self
+
+    def rectify(self):
+        """
+        Positive rectification of the table's data.
+
+        """
+        [obj.rectify() for obj in self._base_objs]
+        self.refreshView()
+        return self
+
+    def pow(self, exp=10):
+        """
+        Apply a power function on each sample in the table.
+
+        :Args:
+
+            exp : float, optional
+                Exponent factor. Defaults to 10.
+
+        """
+        [obj.pow(exp) for obj in self._base_objs]
+        self.refreshView()
+        return self
+
+    def bipolarGain(self, gpos=1, gneg=1):
+        """
+        Apply different gain factor for positive and negative samples.
+
+        :Args:
+
+            gpos : float, optional
+                Gain factor for positive samples. Defaults to 1.
+            gneg : float, optional
+                Gain factor for negative samples. Defaults to 1.
+
+        """
+        [obj.bipolarGain(gpos, gneg) for obj in self._base_objs]
+        self.refreshView()
+        return self
+
+    def lowpass(self, freq=1000):
+        """
+        Apply a one-pole lowpass filter on table's samples.
+
+        :Args:
+
+            freq : float, optional
+                Filter's cutoff, in Hertz. Defaults to 1000.
+
+        """
+        [obj.lowpass(freq) for obj in self._base_objs]
+        self.refreshView()
+        return self
+
+    def fadein(self, dur=0.1):
+        """
+        Apply a gradual increase in the level of the table's samples.
+
+        :Args:
+
+            dur : float, optional
+                Fade in duration, in seconds. Defaults to 0.1.
+
+        """
+        [obj.fadein(dur) for obj in self._base_objs]
+        self.refreshView()
+        return self
+
+    def fadeout(self, dur=0.1):
+        """
+        Apply a gradual decrease in the level of the table's samples.
+
+        :Args:
+
+            dur : float, optional
+                Fade out duration, in seconds. Defaults to 0.1.
+
+        """
+        [obj.fadeout(dur) for obj in self._base_objs]
+        self.refreshView()
+        return self
+
     def copy(self):
         """
         Returns a deep copy of the object.
@@ -1779,6 +1887,7 @@ class VarPort(PyoObject):
         PyoObject.__init__(self, mul, add)
         self._value = value
         self._time = time
+        self._function = function
         value, time, init, function, arg, mul ,add, lmax = convertArgsToLists(value, time, init, function, arg, mul, add)
         self._base_objs = [VarPort_base(wrap(value,i), wrap(time,i), wrap(init,i), wrap(function,i), wrap(arg,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
@@ -1810,6 +1919,20 @@ class VarPort(PyoObject):
         x, lmax = convertArgsToLists(x)
         [obj.setTime(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
 
+    def setFunction(self, x):
+        """
+        Replace the `function` attribute.
+        
+        :Args:
+
+            x : Python function
+                new `function` attribute.
+        
+        """
+        self._function = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setFunction(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
     @property
     def value(self):
         """float. Numerical value to convert.""" 
@@ -1824,6 +1947,13 @@ class VarPort(PyoObject):
     @time.setter
     def time(self, x): self.setTime(x)
 
+    @property
+    def function(self): 
+        """Python callable. Function to be called."""
+        return self._function
+    @function.setter
+    def function(self, x): self.setFunction(x)
+
 class Pow(PyoObject):
     """
     Performs a power function on audio signal.
