@@ -98,7 +98,7 @@ class Server(object):
         
     """
     def __init__(self, sr=44100, nchnls=2, buffersize=256, duplex=1, audio='portaudio', jackname='pyo'):
-        if os.environ.has_key("PYO_SERVER_AUDIO") and "offline" not in audio:
+        if os.environ.has_key("PYO_SERVER_AUDIO") and "offline" not in audio and "embedded" not in audio:
             audio = os.environ["PYO_SERVER_AUDIO"]
         self._time = time
         self._nchnls = nchnls
@@ -637,13 +637,6 @@ class Server(object):
         
         """
         return self._server.setServer()
-        
-    def flush(self):
-        """
-        Flush the server objects. Need a shutdown before working. This is useful if want to flush a script without freeing the buffers
-        
-        """
-        return self._server.flush()
     
     def getInputAddr(self):
         """
