@@ -172,6 +172,20 @@ OscReceiver_delAddress(OscReceiver *self, PyObject *arg)
 	return Py_None;
 }
 
+static PyObject *
+OscReceiver_setValue(OscReceiver *self, PyObject *args, PyObject *kwds)
+{
+    PyObject *address, *value;
+    
+    static char *kwlist[] = {"address", "value", NULL};
+    
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, "OO", kwlist, &address, &value))
+        Py_RETURN_NONE;
+
+    PyDict_SetItem(self->dict, address, value);
+    Py_RETURN_NONE;
+}
+  
 static PyObject * OscReceiver_getServer(OscReceiver* self) { GET_SERVER };
 static PyObject * OscReceiver_getStream(OscReceiver* self) { GET_STREAM };
 
@@ -186,6 +200,7 @@ static PyMethodDef OscReceiver_methods[] = {
 {"_getStream", (PyCFunction)OscReceiver_getStream, METH_NOARGS, "Returns stream object."},
 {"addAddress", (PyCFunction)OscReceiver_addAddress, METH_O, "Add a new address to the dictionary."},
 {"delAddress", (PyCFunction)OscReceiver_delAddress, METH_O, "Remove an address from the dictionary."},
+{"setValue", (PyCFunction)OscReceiver_setValue, METH_VARARGS|METH_KEYWORDS, "Sets value for a specified address."},
 {NULL}  /* Sentinel */
 };
 
@@ -536,19 +551,25 @@ typedef struct {
     lo_address address;
     char *host;
     int port;
+    int count;
+    int bufrate;
 } OscSend;
 
 static void
 OscSend_compute_next_data_frame(OscSend *self)
 {
-    MYFLT *in = Stream_getData((Stream *)self->input_stream);
-    float value = (float)in[0];
+    self->count++;
+    if (self->count >= self->bufrate) {
+        self->count = 0;
+        MYFLT *in = Stream_getData((Stream *)self->input_stream);
+        float value = (float)in[0];
     
-    char *path  = PyString_AsString(self->address_path);
+        char *path  = PyString_AsString(self->address_path);
     
-    if (lo_send(self->address, path, "f", value) == -1) {
-        printf("OSC error %d: %s\n", lo_address_errno(self->address), lo_address_errstr(self->address));
-    }    
+        if (lo_send(self->address, path, "f", value) == -1) {
+            printf("OSC error %d: %s\n", lo_address_errno(self->address), lo_address_errstr(self->address));
+        }
+    }
 }
 
 static int
@@ -588,6 +609,8 @@ OscSend_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     self = (OscSend *)type->tp_alloc(type, 0);
     
     self->host = NULL;
+    self->count = 0;
+    self->bufrate = 1;
     
     INIT_OBJECT_COMMON
     Stream_setFunctionPtr(self->stream, OscSend_compute_next_data_frame);
@@ -617,6 +640,22 @@ OscSend_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     return (PyObject *)self;
 }
 
+static PyObject *
+OscSend_setBufferRate(OscSend *self, PyObject *arg)
+{
+	if (arg == NULL) {
+		Py_INCREF(Py_None);
+		return Py_None;
+	}
+    
+    self->bufrate = PyInt_AsLong(arg);
+    if (self->bufrate < 1)
+        self->bufrate = 1;
+    
+	Py_INCREF(Py_None);
+	return Py_None;
+}
+
 static PyObject * OscSend_getServer(OscSend* self) { GET_SERVER };
 static PyObject * OscSend_getStream(OscSend* self) { GET_STREAM };
 
@@ -635,6 +674,7 @@ static PyMethodDef OscSend_methods[] = {
 {"_getStream", (PyCFunction)OscSend_getStream, METH_NOARGS, "Returns stream object."},
 {"play", (PyCFunction)OscSend_play, METH_VARARGS|METH_KEYWORDS, "Starts computing without sending sound to soundcard."},
 {"stop", (PyCFunction)OscSend_stop, METH_NOARGS, "Stops computing."},
+{"setBufferRate", (PyCFunction)OscSend_setBufferRate, METH_O, "Set how many buffers to wait before sending a new value."},
 {NULL}  /* Sentinel */
 };
 
@@ -1014,6 +1054,8 @@ OscDataReceive_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
 static PyObject * OscDataReceive_getServer(OscDataReceive* self) { GET_SERVER };
 static PyObject * OscDataReceive_getStream(OscDataReceive* self) { GET_STREAM };
+static PyObject * OscDataReceive_play(OscDataReceive *self, PyObject *args, PyObject *kwds) { PLAY };
+static PyObject * OscDataReceive_stop(OscDataReceive *self) { STOP };
 
 static PyObject *
 OscDataReceive_addAddress(OscDataReceive *self, PyObject *arg) {
@@ -1054,6 +1096,8 @@ static PyMemberDef OscDataReceive_members[] = {
 static PyMethodDef OscDataReceive_methods[] = {
     {"getServer", (PyCFunction)OscDataReceive_getServer, METH_NOARGS, "Returns server object."},
     {"_getStream", (PyCFunction)OscDataReceive_getStream, METH_NOARGS, "Returns stream object."},
+    {"play", (PyCFunction)OscDataReceive_play, METH_VARARGS|METH_KEYWORDS, "Starts computing without sending sound to soundcard."},
+    {"stop", (PyCFunction)OscDataReceive_stop, METH_NOARGS, "Stops computing."},
     {"addAddress", (PyCFunction)OscDataReceive_addAddress, METH_O, "Add new paths to the object."},
     {"delAddress", (PyCFunction)OscDataReceive_delAddress, METH_O, "Remove path from the object."},
     {NULL}  /* Sentinel */
@@ -1271,6 +1315,20 @@ OscListReceiver_delAddress(OscListReceiver *self, PyObject *arg)
 	return Py_None;
 }
 
+static PyObject *
+OscListReceiver_setValue(OscListReceiver *self, PyObject *args, PyObject *kwds)
+{
+    PyObject *address, *value;
+
+    static char *kwlist[] = {"address", "value", NULL};
+    
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, "OO", kwlist, &address, &value))
+        Py_RETURN_NONE;
+    
+    PyDict_SetItem(self->dict, address, value);
+    Py_RETURN_NONE;
+}
+
 static PyObject * OscListReceiver_getServer(OscListReceiver* self) { GET_SERVER };
 static PyObject * OscListReceiver_getStream(OscListReceiver* self) { GET_STREAM };
 
@@ -1285,6 +1343,7 @@ static PyMethodDef OscListReceiver_methods[] = {
     {"_getStream", (PyCFunction)OscListReceiver_getStream, METH_NOARGS, "Returns stream object."},
     {"addAddress", (PyCFunction)OscListReceiver_addAddress, METH_O, "Add a new address to the dictionary."},
     {"delAddress", (PyCFunction)OscListReceiver_delAddress, METH_O, "Remove an address from the dictionary."},
+    {"setValue", (PyCFunction)OscListReceiver_setValue, METH_VARARGS|METH_KEYWORDS, "Sets value for a specified address."},
     {NULL}  /* Sentinel */
 };
 
